create_ci_configs: Add Continuous Integration Configuration File

Description Usage Arguments

View source: R/file_create_utils.R

Description

Desired configuration files are created as part of the project creation process. CI options included in ci are available. For internal use. Users should rely on functions in usethis rather than calling create_ci_configs directly.

Usage

1
create_ci_configs(project_root, ci_systems, remote)

Arguments

project_root

root directory for the project being created.

ci_systems

a vector of CI systems selected when create_new_project is called


warlicks/cookiecutteR documentation built on July 6, 2020, 3:23 p.m.