enable_renv: Create project specific library using renv.

Description Usage Arguments

View source: R/enable_renv.R

Description

Intend for internal use only. If you want to create a proejct library outside of the project set up call init directly. User consents to the creation of renv when selecting the option to enable it.

Usage

1
enable_renv(project_root, renv_status)

Arguments

project_root

root directory for the project being created.

renv_status

a boolean indicating if renv should be utilized. Selected interactively when create_new_project is called.


warlicks/cookiecutteR documentation built on July 6, 2020, 3:23 p.m.