Intend for internal use only. If you want to create a proejct library
outside of the project set up call init directly. User
consents to the creation of renv when selecting the option to enable it.
1 | enable_renv(project_root, renv_status)
|
project_root |
root directory for the project being created. |
renv_status |
a boolean indicating if renv should be utilized. Selected
interactively when |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.